#!/bin/sh
# 
# file   urmagic_robotic_sensor.sh
# author Jonathan Savoie <jonathan.savoie@robotiq.com>
# maintainer Nicolas Lauzier <nicolas@robotiq.com">
#  
# Script to install the driver and also the macros
# 

DFU_VERSION="1.1.15"
MOUNTPOINT="$1"
UR_MAGIC_LOCATION="`dirname "${BASH_SOURCE[0]}"`"
echo "magic file location : ${UR_MAGIC_LOCATION}"

LOGGER="/usr/bin/logger"
TAG="-t '$(basename $0)'"

FTDI_CONF_FILE='/etc/modprobe.d/ftdi_sio.conf'
FTDI_CONF_OPTION='options ftdi_sio product=0x6015 vendor=0x0403'
FTDI_CONF_ALIAS='alias usb:v0403p6015d*dc*dsc*dp*ic*isc*ip* ftdi_sio'

function is_files_present () {
	if [ ! -d $1/driver ]; then
		return 1
	fi

	if [ ! -d $1/ftdi_driver ]; then
		return 1
	fi

	if [ ! -d $1/Sensor ]; then
		return 1
	fi

	if [ ! -f $1/boot_driver_sensor.sh ]; then
		return 1
	fi

	if [ ! -f $1/uninstall.sh ]; then
		return 1
	fi

	if [ ! -f $1/script.sh ]; then
		return 1
	fi

	return 0
}

if [ "$1" = "" ] ; then
    $LOGGER -p user.info $TAG "$0: no mountpoint supplied, exiting."
    exit 1 ; fi

# Warn user not to remove USB key
echo "! USB !" | DISPLAY=:0 aosd_cat -R red -x 230 -y -210 -n "Arial Black 80"
echo "Installing Robotiq Force Torque Sensor Program DFU-${DFU_VERSION}" | DISPLAY=:0 aosd_cat -R blue -x 230 -y -310 -n "Arial Black 30"

#check if files are present
if is_files_present ${UR_MAGIC_LOCATION}; then
	echo "files presents"
else
	echo "Installation files missing. Unzip software package properly." | DISPLAY=:0 aosd_cat -R red -x 230 -y -210 -n "Arial Black 80"

	exit 1
fi

echo "Installing DFU-${DFU_VERSION}"


DEST=("/programs")
	
if [ -d ~/Driver_Sensor ]; then
    echo "Robotiq Force Torque Sensor Program Already Installed. Overwriting." | DISPLAY=:0 aosd_cat -R blue -x 230 -y -310 -n "Arial Black 30"
fi

# Stopping and removing the init.d scripts
/etc/init.d/boot_driver_sensor.sh stop
rm -f /etc/init.d/boot_driver_sensor.sh
update-rc.d boot_driver_sensor.sh remove

if [ -f $FTDI_CONF_FILE ]; then
        MSG="FTDI conf file already exists."
        echo $MSG
        echo $MSG | DISPLAY=:0 aosd_cat -R blue -x 230 -y -370 -n "Arial Black 25" &
else
        MSG="FTDI conf file does not exist. Creating it."
        echo $MSG
        echo $MSG | DISPLAY=:0 aosd_cat -R blue -x 230 -y -370 -n "Arial Black 25" &

        echo "# This file allows the ftdi_sio driver to use FT X series." > $FTDI_CONF_FILE
        echo $FTDI_CONF_OPTION >> $FTDI_CONF_FILE
        echo $FTDI_CONF_ALIAS >> $FTDI_CONF_FILE
fi

if [ -f "/lib/modules/`uname -r`/kernel/drivers/usb/serial/ftdi_sio.ko" ]; then 
    echo "FTDI module already loaded."
    echo "FTDI module already loaded." | DISPLAY=:0 aosd_cat -R blue -x 230 -y -310 -n "Arial Black 25" &

    # if a symbolic link exists in this directory, it has been 
    # made by an outdated gripper driver. Remove those links
    # since they prevent ftdi module to be loaded.
    if [ -h "/lib/modules/`uname -r`/ftdi_sio.ko" ]; then
        rm /lib/modules/`uname -r`/ftdi_sio.ko
    fi

    if [ -h "/lib/modules/`uname -r`/usbserial.ko" ]; then
        rm /lib/modules/`uname -r`/usbserial.ko
    fi

    depmod -a
    modprobe ftdi_sio product=0x6015 vendor=0x0403
else
    # Copy the ftdi modules on the system
    cp -f $UR_MAGIC_LOCATION/ftdi_driver/ftdi_sio.ko /root/
    cp -f $UR_MAGIC_LOCATION/ftdi_driver/usbserial.ko /root/
    ln -sf /root/ftdi_sio.ko /lib/modules/$(uname -r)/
    ln -sf /root/usbserial.ko /lib/modules/$(uname -r)/
    
    # Resolve the dependancies and load the modules
    echo "Loading module ftdi_sio" 
    echo "Loading module ftdi_sio" | DISPLAY=:0 aosd_cat -R blue -x 230 -y -310 -n "Arial Black 25" &
    depmod -a
    modprobe ftdi_sio product=0x6015 vendor=0x0403

fi

# Copy the driver
echo "Copying the driver" | DISPLAY=:0 aosd_cat -R blue -x 230 -y -260 -n "Arial Black 30" &
mkdir -p ~/Driver_Sensor
cp -rf $UR_MAGIC_LOCATION/driver/driverSensor ~/Driver_Sensor
chmod +x ~/Driver_Sensor/driverSensor
cp -rf $UR_MAGIC_LOCATION/driver/fuser ~/Driver_Sensor
chmod +x ~/Driver_Sensor/fuser
$LOGGER -p user.info $TAG "$0: copying files from $UR_MAGIC_LOCATION to $DEST..."

# Copy the scripts
echo "Copying the scripts" | DISPLAY=:0 aosd_cat -R blue -x 230 -y -220 -n "Arial Black 30" &
cp -rf $UR_MAGIC_LOCATION/Sensor /programs
$LOGGER -p user.info $TAG "$0: ...copy done."

# Loading the init.d script
echo "Loading the init.d script" | DISPLAY=:0 aosd_cat -R blue -x 230 -y -180 -n "Arial Black 30" &
cp -rf $UR_MAGIC_LOCATION/boot_driver_sensor.sh /etc/init.d/
chmod a+x /etc/init.d/boot_driver_sensor.sh
export PATH=${PATH}:/sbin:/usr/sbin
update-rc.d boot_driver_sensor.sh defaults
$LOGGER -p user.info $TAG "$0: boot_driver copied"

echo "Starting the driver" | DISPLAY=:0 aosd_cat -R blue -x 230 -y -130 -n "Arial Black 30"
/etc/init.d/./boot_driver_sensor.sh start
$LOGGER -p user.info $TAG "$0: driver started"

# Notify user it is ok to remove USB key
echo "<- USB" | DISPLAY=:0 aosd_cat -x 200 -y -210 -n "Arial Black 80"

exit 0;
